NAME = 'redis_kernel'
VERSION = '0.2.1'
LANGUAGE = 'redis'
BANNER = 'redis kernel 0.2.1'
DEFAULT_HOST = 'localhost'
DEFAULT_PORT = '6379'
DISPLAY_NAME = 'Redis'
DESCRIPTION = 'A redis kernel for IPython'